#!/bin/sh

. ./myserver.conf
. ./utils.sh

install_nginx_package()
{
    pkg_add nginx-1.22.0p0 nginx-headers-more-1.22.0 nginx-stream-1.22.0
}

gen_nginx_configuration()
{
    cat > my_configuration/nginx/nginx.conf <<EOF
user www;
worker_processes auto;
pid /var/www/run/nginx.pid;
include /etc/nginx/modules-enabled/*.conf;

events {
        worker_connections 768;
        # multi_accept on;
}

http {

        ##
        # Basic Settings
        ##

        sendfile on;
        tcp_nopush on;
        tcp_nodelay on;
        keepalive_timeout 65;
        types_hash_max_size 2048;
        # server_tokens off;

        include /etc/nginx/mime.types;
        default_type application/octet-stream;

        ##
        # SSL Settings
        ##

        ssl_protocols TLSv1.2; # Dropping SSLv3, ref: POODLE
        ssl_prefer_server_ciphers on;

        ##
        # Logging Settings
        ##

        access_log /var/www/logsnginx/access.log;
        error_log /var/www/logs/nginx/error.log;

        ##
        # Gzip Settings
        ##

        gzip on;
         ##
        # Virtual Host Configs
        ##

        include /etc/nginx/sites-enabled/*;
}
EOF

    openssl dhparam -out default_configuration/nginx/dhparam.pem 2048

}



make_default_homepage()
{
    cat > my_configuration/nginx/site-available/$DOMAIN <<EOF
server {
        listen 80;
        server_name $DOMAIN;

        #Ajout pour les certificats letsencrypt
        include snippets/acme-challenge.conf;

        return 301 https://$http_host$request_uri;

        root /html/$DOMAIN;

}

server {
    listen 443 ssl http2;
    server_name $DOMAIN;


    ssl_certificate         /etc/ssl/$DOMAIN.crt;
    ssl_certificate_key     /etc/ssl/private/$DOMAIN.key;

   #Ajout d'une configuration ssl securise
   include snippets/secure-ssl.conf;

    # Speeds things up a little bit when resuming a session
    # ssl_session_timeout 5m;
    # ssl_session_cache shared:SSL:5m;

        # Ajout pour le certificat letsencrypt
        include snippets/acme-challenge.conf;

        # Ajout pour securiser les headers
        include snippets/secure-headers.conf;
}

    # Path to the root of your installation
   root /html/$DOMAIN;

}
EOF

}

install_nginx_configuration(){
    mkdir /etc/nginx/sites-enabled/
    mkdir /etc/nginx/sites-available/
    mkdir /etc/nginx/snippets/
    cp my_configuration/nginx/nginx.conf /etc/nginx/nginx.conf
    cp my_configuration/nginx/dhparam.pem /etc/nginx/dhparam.pem
    cp my_configuration/nginx/snippets/* /etc/nginx/snippets/
}

install_chroot_env()
{
    mkdir /var/www/etc/ssl/
    install -m 444 -o root -g bin /etc/resolv.conf /var/www/etc/
    install -m 444 -o root -g bin /etc/ssl/cert.pem /etc/ssl/openssl.cnf /var/www/etc/ssl/

}

add_logs_to_newssyslog(){
    cp -v /etc/newsyslog.conf /etc/newsyslog.conf.old
    egrep -v "nginx" /etc/newsyslog.conf > /tmp/newsyslog.conf
    cat >> /tmp/newsyslog.conf <<EOF
/var/www/logs/access.log                644  2     *    \$W0   Z /var/www/run/nginx.pid SIGUSR1
/var/www/logs/error.log                 644  2     250  *     Z /var/www/run/nginx.pid SIGUSR1

EOF
    mv /tmp/newsyslog.conf /etc/newsyslog.conf
}

mkdir my_configuration/nginx/
install_nginx_package
gen_nginx_configuration
install_chroot_env
install_nginx_configuration
restart_webserver_service
